@@ -125,6 +125,7 @@ type LaunchTemplateData struct {
 	UserData, InstanceType, ImageID string
 	BlockDeviceMappings             []BlockDeviceMappings
 	EbsOptimized                    *bool
+	Monitoring                      *Monitoring
 	NetworkInterfaces               []NetworkInterface
 	InstanceMarketOptions           *struct {
 		MarketType  string
@@ -167,3 +168,7 @@ type NetworkInterface struct {
 	NetworkCardIndex         int
 	InterfaceType            string
 }
+
+type Monitoring struct {
+	Enabled bool
+}
